# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🐛 Fixed API ref | [12](https://github.com/laminlabs/lnschema-bionty/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2022-09-06 | 0.2.4
🎨 Import additional modules, species -> species_id | [11](https://github.com/laminlabs/lnschema-bionty/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.2.3
🚚 Rename gene_symbol to symbol, protein_name to name | [10](https://github.com/laminlabs/lnschema-bionty/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.2.2
⬆️ Update schema to match bionty 0.2.0 | [9](https://github.com/laminlabs/lnschema-bionty/pull/9) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-28 | 0.2.1
🚚 Rename `lndb-schema-bionty` to `lnschema-bionty` | [8](https://github.com/laminlabs/lnschema-bionty/pull/8) | [falexwolf](https://github.com/falexwolf) | 2022-08-19 | 0.2.0
🔧 Add schema module id | [7](https://github.com/laminlabs/lnschema-bionty/pull/7) | [falexwolf](https://github.com/falexwolf) | 2022-08-18 |
🍱 Updated the gene table to match new ensembl table | [6](https://github.com/laminlabs/lnschema-bionty/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-18 | 0.1.4
🎨 Changed type of `species` and `entrez_gene_id` in `gene` table to `int` | [5](https://github.com/laminlabs/lnschema-bionty/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-15 | 0.1.3
🚚 Move `biolab` to `lnschema-wetlab` | [4](https://github.com/laminlabs/lnschema-bionty/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-07-31 |
✨ Introduced featureset to replace geneset and proteinset | [2](https://github.com/laminlabs/lnschema-biology/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-31 | 0.1.2
🎨 Changed `resolution` to `platform` in `readout_type` | [commit](https://github.com/laminlabs/lnschema-biology/commit/14552dd71cea463157f29201126ca9a2e259aded) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-23 | 0.1.1
🚚 Move code from `lamindb-schema` | [1](https://github.com/laminlabs/lnschema-biology/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-23 | 0.1.0
